#!/bin/sh

WORD="world"

echo "Starting passphrase tests ..."
echo

# check if directory exists
if [ ! -d secret ]; then
	mkdir -p secret 
	[ $? -ne 0 ] && exit 1
fi

function isCrypted() {
	data=`cat secret/secret-file`
	[[ "$data" == "$WORD" ]] || false;
	if [[ "$?" -eq 0 ]]; then
          echo "File was NOT encrypted; fatal fail"
          exit 1;
        fi
}

function isCrippled() {
	data=`cat secret/secret-file`
	[[ "$data" == "$WORD" ]] || false;
	if [[ "$?" -ne 0 ]]; then
          echo "File was destroyed in process of en-/de-crypting"
	  echo "Can't get the same file as on the beginning"
          exit 1;
        fi
}

function mount() {
	/sbin/mount.ecryptfs secret secret -o "$1" > /dev/null
	if [ "$?" -ne 0 ]; then
	  echo "Fail on mounting ecryptfs dir."
	  exit 1
	fi
}

function unmount() {
	umount secret
	if [ "$?" -ne 0 ]; then
	  echo "Fail on unmounting."
	  exit 1
	fi
}

function test_set() {

	# rnd #1
	mount $1 
	# create crypted file
	echo "$WORD" > secret/secret-file
	unmount
	isCrypted

	# rnd #2
	mount $1
	isCrippled
	unmount
}

# valid passphrase

for key in mykey.pem; do 
	echo "Using key: ${key}"
	echo "-----------------"

	for cipher in aes des3_ede blowfish twofish cast5 cast6; do
		echo -n "Testing cipher [ ${cipher} ], ecryptfs_key_bytes = "
		for bytes in 16 24 32 64 128 256 512 1024 2048 4096 8092; do 
			if [[ ${cipher} == "des3_ede" ]]; then
				bytes=24
			fi
			echo -n "$bytes "
			mnt_opts="key=openssl:keyfile=/root/.ecryptfs/pki/openssl/${key}:passwd_file=passfile.txt,ecryptfs_cipher=${cipher},ecryptfs_key_bytes=${bytes},verbosity=0"
			test_set ${mnt_opts}
			if [ $? -ne 0 ]; then 
				echo "Test failed for [ ${cipher} ]"; 
			fi
			# Triple DES is ecryptfs_key_bytes = 24 only
			if [[ ${cipher} == "des3_ede" ]]; then
				break
			fi
		done
		echo
	done
	echo
done

rmdir secret

echo "Finished passphrase tests ..."

exit 0

